crafted_ui library

Support for doing something awesome.

More dartdocs go here.

Classes

AppColor
AssetsPath
Awesome
Checks if you are awesome. Spoiler: you are.
Corners
CraftedButton
CraftedCard
CraftedCarousel
CraftedCheckBox
CraftedContainer
CraftedDatepicker
CraftedDivider
CraftedDropdown
CraftedExpandableText
CraftedImage
CraftedInput
CraftedLabelValue
CraftedMouseRegion
CraftedThemeProvider
CraftedVideoPlayer
Fonts
Fonts - A list of Font Families, this is uses by the TextStyles class to create concrete styles.
FontSizes
Font Sizes You can use these directly if you need, but usually there should be a predefined style in TextStyles.
FontW
TextStyles - All the core text styles for the app should be declared here. Don't try and create every variant in existence here, just the high level ones. More specific variants can be created on the fly using style.copyWith() newStyle = TextStyles.body1.copyWith(lineHeight: 2, color: Colors.red)
IconSizes
Insets
Lorem
////////////////////////////////////////////////////////////// Styles - Contains the design system for the entire app. Includes paddings, text styles, timings etc. Does not include colors, check AppTheme file for that. Lorem for test
Margin
Screen
ScreenSize
Shadows
Sizes
Strokes
TextStyles
Times
Used for all animations in the app
Wrapper
WrapperContainer